;; Generated package description from evil-surround.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "evil-surround" "1.0.4.0.20260601.24" "emulate surround.vim from Vim" '((evil "1.2.12")) :commit "c0d2519424933b117b3b2331d07728295866b8e5" :url "https://elpa.nongnu.org/nongnu/evil-surround.html" :authors '(("Tim Harper" . "timcharperatgmaildotcom") ("Vegard ye" . "vegard_oyeathotmaildotcom")) :maintainer '("Tom Dalziel" . "tom.dalziel@gmail.com") :keywords '("emulation" "vi" "evil"))
